@@ -2,9 +2,16 @@
 Pyndl - Naive Discriminative Learning in Python
 ===============================================
 
-*pyndl* is an implementation of Naive Discriminative Learning in Python. It was
-created to analyse huge amounts of text file corpora. Especially, it allows to
-efficiently apply the Rescorla-Wagner learning rule to these corpora.
+*pyndl* implements Naïve Discriminative Learning (NDL) in Python. NDL is an
+incremental learning algorithm grounded in the principles of discrimination 
+learning and motivated by animal and human learning research. Lately, NDL 
+has become a popular tool in language research to examine large corpora and
+vocabularies, with 750,000 spoken word tokens and a vocabulary size of 52,402
+word types. In contrast to previous implementations, *pyndl* allows for a 
+broader range of analysis, including non-English languages, adds further 
+learning rules and provides better maintainability while having the same 
+fast processing speed. As of today, it supports multiple research groups 
+in their work and led to several scientific publications.
 
 """
 
@@ -20,31 +27,12 @@ try:
 except ModuleNotFoundError:  # this should only happend during setup phase
     Requirement = None
 
-
-__author__ = ('Konstantin Sering, Marc Weitz, '
-              'David-Elias Künstle, Lennard Schneider, '
-              'Elnaz Shafaei-Bajestan')
-__author_email__ = 'konstantin.sering@uni-tuebingen.de'
-__version__ = '0.8.2'
-__license__ = 'MIT'
-__description__ = ('Naive discriminative learning implements learning and '
-                   'classification models based on the Rescorla-Wagner '
-                   'equations.')
-__classifiers__ = [
-    'Development Status :: 4 - Beta',
-    'Environment :: Console',
-    'Intended Audience :: Science/Research',
-    'License :: OSI Approved :: MIT License',
-    'Operating System :: POSIX :: Linux',
-    'Operating System :: MacOS',
-    'Programming Language :: Python',
-    'Programming Language :: Python :: 3.8',
-    'Programming Language :: Python :: 3.9',
-    'Programming Language :: Python :: 3 :: Only',
-    'Topic :: Scientific/Engineering',
-    'Topic :: Scientific/Engineering :: Artificial Intelligence',
-    'Topic :: Scientific/Engineering :: Information Analysis',
-    ]
+try:
+    from importlib import metadata
+    __version__ = metadata.version(__package__)
+except metadata.PackageNotFoundError:
+    import toml
+    __version__ = toml.load("pyproject.toml")["tool"]["poetry"]["version"] + "dev"
 
 
 def sysinfo():
